Index: src/mips/builtins-mips.cc |
diff --git a/src/mips/builtins-mips.cc b/src/mips/builtins-mips.cc |
index 420e2ca3b4345eef9edd7179361826ecd986fe8a..036847e1b3683fdf8682cd84c5b20ae5e41962ec 100644 |
--- a/src/mips/builtins-mips.cc |
+++ b/src/mips/builtins-mips.cc |
@@ -974,9 +974,9 @@ static void Generate_JSConstructStubHelper(MacroAssembler* masm, |
__ Branch(&use_receiver, eq, t0, Operand(zero_reg)); |
// If the type of the result (stored in its map) is less than |
// FIRST_JS_OBJECT_TYPE, it is not an object in the ECMA sense. |
__ GetObjectType(v0, a3, a3); |
- __ Branch(&exit, greater_equal, a3, Operand(FIRST_JS_OBJECT_TYPE)); |
+ __ Branch(&exit, greater_equal, a3, Operand(FIRST_SPEC_OBJECT_TYPE)); |
// Throw away the result of the constructor invocation and use the |
// on-stack receiver as the result. |
@@ -1234,10 +1234,9 @@ void Builtins::Generate_FunctionCall(MacroAssembler* masm) { |
__ LoadRoot(a3, Heap::kNullValueRootIndex); |
__ Branch(&use_global_receiver, eq, a2, Operand(a3)); |
- STATIC_ASSERT(LAST_JS_OBJECT_TYPE + 1 == LAST_TYPE); |
- STATIC_ASSERT(LAST_TYPE == JS_FUNCTION_TYPE); |
+ STATIC_ASSERT(LAST_SPEC_OBJECT_TYPE == LAST_TYPE); |
__ GetObjectType(a2, a3, a3); |
- __ Branch(&shift_arguments, ge, a3, Operand(FIRST_JS_OBJECT_TYPE)); |
+ __ Branch(&shift_arguments, ge, a3, Operand(FIRST_SPEC_OBJECT_TYPE)); |
__ bind(&convert_to_object); |
__ EnterInternalFrame(); // In order to preserve argument count. |
@@ -1416,10 +1415,9 @@ void Builtins::Generate_FunctionApply(MacroAssembler* masm) { |
// Check if the receiver is already a JavaScript object. |
// a0: receiver |
- STATIC_ASSERT(LAST_JS_OBJECT_TYPE + 1 == LAST_TYPE); |
- STATIC_ASSERT(LAST_TYPE == JS_FUNCTION_TYPE); |
+ STATIC_ASSERT(LAST_SPEC_OBJECT_TYPE == LAST_TYPE); |
__ GetObjectType(a0, a1, a1); |
- __ Branch(&push_receiver, ge, a1, Operand(FIRST_JS_OBJECT_TYPE)); |
+ __ Branch(&push_receiver, ge, a1, Operand(FIRST_SPEC_OBJECT_TYPE)); |
// Convert the receiver to a regular object. |
// a0: receiver |
@@ -974,9 +974,9 @@ static void Generate_JSConstructStubHelper(MacroAssembler* masm, |
__ Branch(&use_receiver, eq, t0, Operand(zero_reg)); |
// If the type of the result (stored in its map) is less than |
- // FIRST_JS_OBJECT_TYPE, it is not an object in the ECMA sense. |
+ // FIRST_SPEC_OBJECT_TYPE, it is not an object in the ECMA sense. |
__ GetObjectType(v0, a3, a3); |